@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2014 Lukas W <lukaswhl/at/gmail.com>
  *
- * This file is part of LMMS - http://lmms.io
+ * This file is part of LMMS - https://lmms.io
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@
 #ifndef FILEDIALOG_H
 #define FILEDIALOG_H
 
-#include <QtGui/QFileDialog>
+#include <QFileDialog>
 
 #include "export.h"
 
